You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2014/05/14 08:27:57 UTC

[46/50] [abbrv] git commit: Cleans up new extension point

Cleans up new extension point


Project: http://git-wip-us.apache.org/repos/asf/struts/repo
Commit: http://git-wip-us.apache.org/repos/asf/struts/commit/e8e5b51b
Tree: http://git-wip-us.apache.org/repos/asf/struts/tree/e8e5b51b
Diff: http://git-wip-us.apache.org/repos/asf/struts/diff/e8e5b51b

Branch: refs/heads/feature/exclude-object-class
Commit: e8e5b51bc64e71cc7645c1083b33e1942bf4a03d
Parents: 833a07e
Author: Lukasz Lenart <lu...@apache.org>
Authored: Wed May 14 08:25:00 2014 +0200
Committer: Lukasz Lenart <lu...@apache.org>
Committed: Wed May 14 08:25:00 2014 +0200

----------------------------------------------------------------------
 .../org/apache/struts2/config/DefaultBeanSelectionProvider.java  | 4 ++--
 .../java/org/apache/struts2/interceptor/CookieInterceptor.java   | 2 +-
 core/src/main/resources/struts-default.xml                       | 4 +---
 3 files changed, 4 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/struts/blob/e8e5b51b/core/src/main/java/org/apache/struts2/config/DefaultBeanSelectionProvider.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java b/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java
index 8998c5c..dbe47ce 100644
--- a/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java
+++ b/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java
@@ -180,7 +180,7 @@ public class CookieInterceptor extends AbstractInterceptor {
 
     private ExcludedPatternsChecker excludedPatternsChecker;
 
-    @Inject(StrutsConstants.STRUTS_EXCLUDED_PATTERNS_CHECKER)
+    @Inject
     public void setExcludedPatternsChecker(ExcludedPatternsChecker excludedPatternsChecker) {
         this.excludedPatternsChecker = excludedPatternsChecker;
     }

http://git-wip-us.apache.org/repos/asf/struts/blob/e8e5b51b/core/src/main/resources/struts-default.xml
----------------------------------------------------------------------
diff --git a/core/src/main/resources/struts-default.xml b/core/src/main/resources/struts-default.xml
index f2fb922..2d74b4f 100644
--- a/core/src/main/resources/struts-default.xml
+++ b/core/src/main/resources/struts-default.xml
@@ -144,9 +144,7 @@
     <bean type="ognl.PropertyAccessor" name="java.util.HashSet" class="com.opensymphony.xwork2.ognl.accessor.XWorkCollectionPropertyAccessor" />
     <bean type="ognl.PropertyAccessor" name="java.util.HashMap" class="com.opensymphony.xwork2.ognl.accessor.XWorkMapPropertyAccessor" />
 
-    <bean type="com.opensymphony.xwork2.ExcludedPatternsChecker" name="struts" class="com.opensymphony.xwork2.DefaultExcludedPatternsChecker" scope="request"/>
-
-    <constant name="struts.excludedPatterns.checker" value="struts"/>
+    <bean type="com.opensymphony.xwork2.ExcludedPatternsChecker" name="struts" class="com.opensymphony.xwork2.DefaultExcludedPatternsChecker" />
 
     <package name="struts-default" abstract="true">
         <result-types>
diff --git a/core/src/main/java/org/apache/struts2/config/DefaultBeanSelectionProvider.java b/core/src/main/java/org/apache/struts2/config/DefaultBeanSelectionProvider.java
index 5296b41..5c29e78 100644
--- a/core/src/main/java/org/apache/struts2/config/DefaultBeanSelectionProvider.java
+++ b/core/src/main/java/org/apache/struts2/config/DefaultBeanSelectionProvider.java
@@ -390,8 +390,8 @@ public class DefaultBeanSelectionProvider extends AbstractBeanSelectionProvider
 
         alias(DispatcherErrorHandler.class, StrutsConstants.STRUTS_DISPATCHER_ERROR_HANDLER, builder, props);
 
-        /** Checker is used mostly in interceptors, so there be one instance of checker per interceptor with Scope.REQUEST **/
-        alias(ExcludedPatternsChecker.class, StrutsConstants.STRUTS_EXCLUDED_PATTERNS_CHECKER, builder, props, Scope.REQUEST);
+        /** Checker is used mostly in interceptors, so there be one instance of checker per interceptor with Scope.DEFAULT **/
+        alias(ExcludedPatternsChecker.class, StrutsConstants.STRUTS_EXCLUDED_PATTERNS_CHECKER, builder, props, Scope.DEFAULT);
 
         switchDevMode(props);
 

http://git-wip-us.apache.org/repos/asf/struts/blob/e8e5b51b/core/src/main/java/org/apache/struts2/interceptor/CookieInterceptor.java
----------------------------------------------------------------------